.onLoad <- function(lib,pkg) {
	require(methods)
	cat("FLCore 1.3-0 - \"The Dutch Hamster Redux\" \n")
}
